Method: Aws::WorkSpacesWeb::Types::CreateBrowserSettingsRequest#client_token

Defined in:
lib/aws-sdk-workspacesweb/types.rb

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully, subsequent retries with the same client token returns the result from the original successful request.

If you do not specify a client token, one is automatically generated by the Amazon Web Services SDK.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


687
688
689
690
691
692
693
694
695
696
# File 'lib/aws-sdk-workspacesweb/types.rb', line 687

class CreateBrowserSettingsRequest < Struct.new(
  :tags,
  :customer_managed_key,
  :additional_encryption_context,
  :browser_policy,
  :client_token,
  :web_content_filtering_policy)
  SENSITIVE = [:tags, :browser_policy]
  include Aws::Structure
end