Class: Aws::WorkSpacesWeb::Types::IconImageInput

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-workspacesweb/types.rb

Overview

Note:

IconImageInput is a union - when making an API calls you must set exactly one of the members.

The input for an icon image (logo or favicon). Provide either a binary image file or an S3 URI pointing to the image file. Maximum 100 KB in JPEG, PNG, or ICO format.

Defined Under Namespace

Classes: Blob, S3Uri, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#blobString

The image provided as a binary image file.

Returns:

  • (String)


2216
2217
2218
2219
2220
2221
2222
2223
2224
2225
2226
2227
# File 'lib/aws-sdk-workspacesweb/types.rb', line 2216

class IconImageInput < Struct.new(
  :blob,
  :s3_uri,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Blob < IconImageInput; end
  class S3Uri < IconImageInput; end
  class Unknown < IconImageInput; end
end

#s3_uriString

The S3 URI pointing to the image file. The URI must use the format s3://bucket-name/key-name. You must have read access to the S3 object.

Returns:

  • (String)


2216
2217
2218
2219
2220
2221
2222
2223
2224
2225
2226
2227
# File 'lib/aws-sdk-workspacesweb/types.rb', line 2216

class IconImageInput < Struct.new(
  :blob,
  :s3_uri,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Blob < IconImageInput; end
  class S3Uri < IconImageInput; end
  class Unknown < IconImageInput; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



2216
2217
2218
# File 'lib/aws-sdk-workspacesweb/types.rb', line 2216

def unknown
  @unknown
end