Method: Aws::WorkSpacesWeb::Types::CreateUserSettingsRequest#client_token
- Defined in:
- lib/aws-sdk-workspacesweb/types.rb
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully, subsequent retries with the same client token returns the result from the original successful request.
If you do not specify a client token, one is automatically generated by the Amazon Web Services SDK.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 |
# File 'lib/aws-sdk-workspacesweb/types.rb', line 1373 class CreateUserSettingsRequest < Struct.new( :copy_allowed, :paste_allowed, :download_allowed, :upload_allowed, :print_allowed, :tags, :disconnect_timeout_in_minutes, :idle_disconnect_timeout_in_minutes, :client_token, :cookie_synchronization_configuration, :customer_managed_key, :additional_encryption_context, :deep_link_allowed, :toolbar_configuration, :branding_configuration_input, :web_authn_allowed) SENSITIVE = [:tags, :cookie_synchronization_configuration] include Aws::Structure end |