Method: Aws::WorkSpacesWeb::Types::CreateUserSettingsRequest#toolbar_configuration
- Defined in:
- lib/aws-sdk-workspacesweb/types.rb
#toolbar_configuration ⇒ Types::ToolbarConfiguration
The configuration of the toolbar. This allows administrators to select the toolbar type and visual mode, set maximum display resolution for sessions, and choose which items are visible to end users during their sessions. If administrators do not modify these settings, end users retain control over their toolbar preferences.
1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 |
# File 'lib/aws-sdk-workspacesweb/types.rb', line 1373 class CreateUserSettingsRequest < Struct.new( :copy_allowed, :paste_allowed, :download_allowed, :upload_allowed, :print_allowed, :tags, :disconnect_timeout_in_minutes, :idle_disconnect_timeout_in_minutes, :client_token, :cookie_synchronization_configuration, :customer_managed_key, :additional_encryption_context, :deep_link_allowed, :toolbar_configuration, :branding_configuration_input, :web_authn_allowed) SENSITIVE = [:tags, :cookie_synchronization_configuration] include Aws::Structure end |