Class: Aws::WorkSpacesWeb::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::WorkSpacesWeb::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-workspacesweb/client.rb,
sig/client.rbs
Overview
An API client for WorkSpacesWeb. To construct a client, you need to configure a :region and :credentials.
client = Aws::WorkSpacesWeb::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AssociateBrowserSettingsResponseSuccess, _AssociateDataProtectionSettingsResponseSuccess, _AssociateIpAccessSettingsResponseSuccess, _AssociateNetworkSettingsResponseSuccess, _AssociateSessionLoggerResponseSuccess, _AssociateTrustStoreResponseSuccess, _AssociateUserAccessLoggingSettingsResponseSuccess, _AssociateUserSettingsResponseSuccess, _CreateBrowserSettingsResponseSuccess, _CreateDataProtectionSettingsResponseSuccess, _CreateIdentityProviderResponseSuccess, _CreateIpAccessSettingsResponseSuccess, _CreateNetworkSettingsResponseSuccess, _CreatePortalResponseSuccess, _CreateSessionLoggerResponseSuccess, _CreateTrustStoreResponseSuccess, _CreateUserAccessLoggingSettingsResponseSuccess, _CreateUserSettingsResponseSuccess, _DeleteBrowserSettingsResponseSuccess, _DeleteDataProtectionSettingsResponseSuccess, _DeleteIdentityProviderResponseSuccess, _DeleteIpAccessSettingsResponseSuccess, _DeleteNetworkSettingsResponseSuccess, _DeletePortalResponseSuccess, _DeleteSessionLoggerResponseSuccess, _DeleteTrustStoreResponseSuccess, _DeleteUserAccessLoggingSettingsResponseSuccess, _DeleteUserSettingsResponseSuccess, _DisassociateBrowserSettingsResponseSuccess, _DisassociateDataProtectionSettingsResponseSuccess, _DisassociateIpAccessSettingsResponseSuccess, _DisassociateNetworkSettingsResponseSuccess, _DisassociateSessionLoggerResponseSuccess, _DisassociateTrustStoreResponseSuccess, _DisassociateUserAccessLoggingSettingsResponseSuccess, _DisassociateUserSettingsResponseSuccess, _ExpireSessionResponseSuccess, _GetBrowserSettingsResponseSuccess, _GetDataProtectionSettingsResponseSuccess, _GetIdentityProviderResponseSuccess, _GetIpAccessSettingsResponseSuccess, _GetNetworkSettingsResponseSuccess, _GetPortalResponseSuccess, _GetPortalServiceProviderMetadataResponseSuccess, _GetSessionLoggerResponseSuccess, _GetSessionResponseSuccess, _GetTrustStoreCertificateResponseSuccess, _GetTrustStoreResponseSuccess, _GetUserAccessLoggingSettingsResponseSuccess, _GetUserSettingsResponseSuccess, _ListBrowserSettingsResponseSuccess, _ListDataProtectionSettingsResponseSuccess, _ListIdentityProvidersResponseSuccess, _ListIpAccessSettingsResponseSuccess, _ListNetworkSettingsResponseSuccess, _ListPortalsResponseSuccess, _ListSessionLoggersResponseSuccess, _ListSessionsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListTrustStoreCertificatesResponseSuccess, _ListTrustStoresResponseSuccess, _ListUserAccessLoggingSettingsResponseSuccess, _ListUserSettingsResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateBrowserSettingsResponseSuccess, _UpdateDataProtectionSettingsResponseSuccess, _UpdateIdentityProviderResponseSuccess, _UpdateIpAccessSettingsResponseSuccess, _UpdateNetworkSettingsResponseSuccess, _UpdatePortalResponseSuccess, _UpdateSessionLoggerResponseSuccess, _UpdateTrustStoreResponseSuccess, _UpdateUserAccessLoggingSettingsResponseSuccess, _UpdateUserSettingsResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_browser_settings(params = {}) ⇒ Types::AssociateBrowserSettingsResponse
Associates a browser settings resource with a web portal.
-
#associate_data_protection_settings(params = {}) ⇒ Types::AssociateDataProtectionSettingsResponse
Associates a data protection settings resource with a web portal.
-
#associate_ip_access_settings(params = {}) ⇒ Types::AssociateIpAccessSettingsResponse
Associates an IP access settings resource with a web portal.
-
#associate_network_settings(params = {}) ⇒ Types::AssociateNetworkSettingsResponse
Associates a network settings resource with a web portal.
-
#associate_session_logger(params = {}) ⇒ Types::AssociateSessionLoggerResponse
Associates a session logger with a portal.
-
#associate_trust_store(params = {}) ⇒ Types::AssociateTrustStoreResponse
Associates a trust store with a web portal.
-
#associate_user_access_logging_settings(params = {}) ⇒ Types::AssociateUserAccessLoggingSettingsResponse
Associates a user access logging settings resource with a web portal.
-
#associate_user_settings(params = {}) ⇒ Types::AssociateUserSettingsResponse
Associates a user settings resource with a web portal.
-
#create_browser_settings(params = {}) ⇒ Types::CreateBrowserSettingsResponse
Creates a browser settings resource that can be associated with a web portal.
-
#create_data_protection_settings(params = {}) ⇒ Types::CreateDataProtectionSettingsResponse
Creates a data protection settings resource that can be associated with a web portal.
-
#create_identity_provider(params = {}) ⇒ Types::CreateIdentityProviderResponse
Creates an identity provider resource that is then associated with a web portal.
-
#create_ip_access_settings(params = {}) ⇒ Types::CreateIpAccessSettingsResponse
Creates an IP access settings resource that can be associated with a web portal.
-
#create_network_settings(params = {}) ⇒ Types::CreateNetworkSettingsResponse
Creates a network settings resource that can be associated with a web portal.
-
#create_portal(params = {}) ⇒ Types::CreatePortalResponse
Creates a web portal.
-
#create_session_logger(params = {}) ⇒ Types::CreateSessionLoggerResponse
Creates a session logger.
-
#create_trust_store(params = {}) ⇒ Types::CreateTrustStoreResponse
Creates a trust store that can be associated with a web portal.
-
#create_user_access_logging_settings(params = {}) ⇒ Types::CreateUserAccessLoggingSettingsResponse
Creates a user access logging settings resource that can be associated with a web portal.
-
#create_user_settings(params = {}) ⇒ Types::CreateUserSettingsResponse
Creates a user settings resource that can be associated with a web portal.
-
#delete_browser_settings(params = {}) ⇒ Struct
Deletes browser settings.
-
#delete_data_protection_settings(params = {}) ⇒ Struct
Deletes data protection settings.
-
#delete_identity_provider(params = {}) ⇒ Struct
Deletes the identity provider.
-
#delete_ip_access_settings(params = {}) ⇒ Struct
Deletes IP access settings.
-
#delete_network_settings(params = {}) ⇒ Struct
Deletes network settings.
-
#delete_portal(params = {}) ⇒ Struct
Deletes a web portal.
-
#delete_session_logger(params = {}) ⇒ Struct
Deletes a session logger resource.
-
#delete_trust_store(params = {}) ⇒ Struct
Deletes the trust store.
-
#delete_user_access_logging_settings(params = {}) ⇒ Struct
Deletes user access logging settings.
-
#delete_user_settings(params = {}) ⇒ Struct
Deletes user settings.
-
#disassociate_browser_settings(params = {}) ⇒ Struct
Disassociates browser settings from a web portal.
-
#disassociate_data_protection_settings(params = {}) ⇒ Struct
Disassociates data protection settings from a web portal.
-
#disassociate_ip_access_settings(params = {}) ⇒ Struct
Disassociates IP access settings from a web portal.
-
#disassociate_network_settings(params = {}) ⇒ Struct
Disassociates network settings from a web portal.
-
#disassociate_session_logger(params = {}) ⇒ Struct
Disassociates a session logger from a portal.
-
#disassociate_trust_store(params = {}) ⇒ Struct
Disassociates a trust store from a web portal.
-
#disassociate_user_access_logging_settings(params = {}) ⇒ Struct
Disassociates user access logging settings from a web portal.
-
#disassociate_user_settings(params = {}) ⇒ Struct
Disassociates user settings from a web portal.
-
#expire_session(params = {}) ⇒ Struct
Expires an active secure browser session.
-
#get_browser_settings(params = {}) ⇒ Types::GetBrowserSettingsResponse
Gets browser settings.
-
#get_data_protection_settings(params = {}) ⇒ Types::GetDataProtectionSettingsResponse
Gets the data protection settings.
-
#get_identity_provider(params = {}) ⇒ Types::GetIdentityProviderResponse
Gets the identity provider.
-
#get_ip_access_settings(params = {}) ⇒ Types::GetIpAccessSettingsResponse
Gets the IP access settings.
-
#get_network_settings(params = {}) ⇒ Types::GetNetworkSettingsResponse
Gets the network settings.
-
#get_portal(params = {}) ⇒ Types::GetPortalResponse
Gets the web portal.
-
#get_portal_service_provider_metadata(params = {}) ⇒ Types::GetPortalServiceProviderMetadataResponse
Gets the service provider metadata.
-
#get_session(params = {}) ⇒ Types::GetSessionResponse
Gets information for a secure browser session.
-
#get_session_logger(params = {}) ⇒ Types::GetSessionLoggerResponse
Gets details about a specific session logger resource.
-
#get_trust_store(params = {}) ⇒ Types::GetTrustStoreResponse
Gets the trust store.
-
#get_trust_store_certificate(params = {}) ⇒ Types::GetTrustStoreCertificateResponse
Gets the trust store certificate.
-
#get_user_access_logging_settings(params = {}) ⇒ Types::GetUserAccessLoggingSettingsResponse
Gets user access logging settings.
-
#get_user_settings(params = {}) ⇒ Types::GetUserSettingsResponse
Gets user settings.
-
#list_browser_settings(params = {}) ⇒ Types::ListBrowserSettingsResponse
Retrieves a list of browser settings.
-
#list_data_protection_settings(params = {}) ⇒ Types::ListDataProtectionSettingsResponse
Retrieves a list of data protection settings.
-
#list_identity_providers(params = {}) ⇒ Types::ListIdentityProvidersResponse
Retrieves a list of identity providers for a specific web portal.
-
#list_ip_access_settings(params = {}) ⇒ Types::ListIpAccessSettingsResponse
Retrieves a list of IP access settings.
-
#list_network_settings(params = {}) ⇒ Types::ListNetworkSettingsResponse
Retrieves a list of network settings.
-
#list_portals(params = {}) ⇒ Types::ListPortalsResponse
Retrieves a list or web portals.
-
#list_session_loggers(params = {}) ⇒ Types::ListSessionLoggersResponse
Lists all available session logger resources.
-
#list_sessions(params = {}) ⇒ Types::ListSessionsResponse
Lists information for multiple secure browser sessions from a specific portal.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves a list of tags for a resource.
-
#list_trust_store_certificates(params = {}) ⇒ Types::ListTrustStoreCertificatesResponse
Retrieves a list of trust store certificates.
-
#list_trust_stores(params = {}) ⇒ Types::ListTrustStoresResponse
Retrieves a list of trust stores.
-
#list_user_access_logging_settings(params = {}) ⇒ Types::ListUserAccessLoggingSettingsResponse
Retrieves a list of user access logging settings.
-
#list_user_settings(params = {}) ⇒ Types::ListUserSettingsResponse
Retrieves a list of user settings.
-
#tag_resource(params = {}) ⇒ Struct
Adds or overwrites one or more tags for the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from the specified resource.
-
#update_browser_settings(params = {}) ⇒ Types::UpdateBrowserSettingsResponse
Updates browser settings.
-
#update_data_protection_settings(params = {}) ⇒ Types::UpdateDataProtectionSettingsResponse
Updates data protection settings.
-
#update_identity_provider(params = {}) ⇒ Types::UpdateIdentityProviderResponse
Updates the identity provider.
-
#update_ip_access_settings(params = {}) ⇒ Types::UpdateIpAccessSettingsResponse
Updates IP access settings.
-
#update_network_settings(params = {}) ⇒ Types::UpdateNetworkSettingsResponse
Updates network settings.
-
#update_portal(params = {}) ⇒ Types::UpdatePortalResponse
Updates a web portal.
-
#update_session_logger(params = {}) ⇒ Types::UpdateSessionLoggerResponse
Updates the details of a session logger.
-
#update_trust_store(params = {}) ⇒ Types::UpdateTrustStoreResponse
Updates the trust store.
-
#update_user_access_logging_settings(params = {}) ⇒ Types::UpdateUserAccessLoggingSettingsResponse
Updates the user access logging settings.
-
#update_user_settings(params = {}) ⇒ Types::UpdateUserSettingsResponse
Updates the user settings.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-workspacesweb/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4539 4540 4541 |
# File 'lib/aws-sdk-workspacesweb/client.rb', line 4539 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4542 4543 4544 |
# File 'lib/aws-sdk-workspacesweb/client.rb', line 4542 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#associate_browser_settings(params = {}) ⇒ Types::AssociateBrowserSettingsResponse
Associates a browser settings resource with a web portal.
87 |
# File 'sig/client.rbs', line 87
def associate_browser_settings: (
|
#associate_data_protection_settings(params = {}) ⇒ Types::AssociateDataProtectionSettingsResponse
Associates a data protection settings resource with a web portal.
99 |
# File 'sig/client.rbs', line 99
def associate_data_protection_settings: (
|
#associate_ip_access_settings(params = {}) ⇒ Types::AssociateIpAccessSettingsResponse
Associates an IP access settings resource with a web portal.
111 |
# File 'sig/client.rbs', line 111
def associate_ip_access_settings: (
|
#associate_network_settings(params = {}) ⇒ Types::AssociateNetworkSettingsResponse
Associates a network settings resource with a web portal.
123 |
# File 'sig/client.rbs', line 123
def associate_network_settings: (
|
#associate_session_logger(params = {}) ⇒ Types::AssociateSessionLoggerResponse
Associates a session logger with a portal.
135 |
# File 'sig/client.rbs', line 135
def associate_session_logger: (
|
#associate_trust_store(params = {}) ⇒ Types::AssociateTrustStoreResponse
Associates a trust store with a web portal.
147 |
# File 'sig/client.rbs', line 147
def associate_trust_store: (
|
#associate_user_access_logging_settings(params = {}) ⇒ Types::AssociateUserAccessLoggingSettingsResponse
Associates a user access logging settings resource with a web portal.
159 |
# File 'sig/client.rbs', line 159
def associate_user_access_logging_settings: (
|
#associate_user_settings(params = {}) ⇒ Types::AssociateUserSettingsResponse
Associates a user settings resource with a web portal.
171 |
# File 'sig/client.rbs', line 171
def associate_user_settings: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4512 4513 4514 4515 4516 4517 4518 4519 4520 4521 4522 4523 4524 4525 4526 4527 4528 |
# File 'lib/aws-sdk-workspacesweb/client.rb', line 4512 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::WorkSpacesWeb') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-workspacesweb' context[:gem_version] = '1.66.0' Seahorse::Client::Request.new(handlers, context) end |
#create_browser_settings(params = {}) ⇒ Types::CreateBrowserSettingsResponse
Creates a browser settings resource that can be associated with a web portal. Once associated with a web portal, browser settings control how the browser will behave once a user starts a streaming session for the web portal.
182 |
# File 'sig/client.rbs', line 182
def create_browser_settings: (
|
#create_data_protection_settings(params = {}) ⇒ Types::CreateDataProtectionSettingsResponse
Creates a data protection settings resource that can be associated with a web portal.
206 |
# File 'sig/client.rbs', line 206
def create_data_protection_settings: (
|
#create_identity_provider(params = {}) ⇒ Types::CreateIdentityProviderResponse
Creates an identity provider resource that is then associated with a web portal.
227 |
# File 'sig/client.rbs', line 227
def create_identity_provider: (
|
#create_ip_access_settings(params = {}) ⇒ Types::CreateIpAccessSettingsResponse
Creates an IP access settings resource that can be associated with a web portal.
247 |
# File 'sig/client.rbs', line 247
def create_ip_access_settings: (
|
#create_network_settings(params = {}) ⇒ Types::CreateNetworkSettingsResponse
Creates a network settings resource that can be associated with a web portal. Once associated with a web portal, network settings define how streaming instances will connect with your specified VPC.
273 |
# File 'sig/client.rbs', line 273
def create_network_settings: (
|
#create_portal(params = {}) ⇒ Types::CreatePortalResponse
Creates a web portal.
293 |
# File 'sig/client.rbs', line 293
def create_portal: (
|
#create_session_logger(params = {}) ⇒ Types::CreateSessionLoggerResponse
Creates a session logger.
316 |
# File 'sig/client.rbs', line 316
def create_session_logger: (
|
#create_trust_store(params = {}) ⇒ Types::CreateTrustStoreResponse
Creates a trust store that can be associated with a web portal. A trust store contains certificate authority (CA) certificates. Once associated with a web portal, the browser in a streaming session will recognize certificates that have been issued using any of the CAs in the trust store. If your organization has internal websites that use certificates issued by private CAs, you should add the private CA certificate to the trust store.
341 |
# File 'sig/client.rbs', line 341
def create_trust_store: (
|
#create_user_access_logging_settings(params = {}) ⇒ Types::CreateUserAccessLoggingSettingsResponse
Creates a user access logging settings resource that can be associated with a web portal.
358 |
# File 'sig/client.rbs', line 358
def create_user_access_logging_settings: (
|
#create_user_settings(params = {}) ⇒ Types::CreateUserSettingsResponse
Creates a user settings resource that can be associated with a web portal. Once associated with a web portal, user settings control how users can transfer data between a streaming session and the their local devices.
375 |
# File 'sig/client.rbs', line 375
def create_user_settings: (
|
#delete_browser_settings(params = {}) ⇒ Struct
Deletes browser settings.
425 |
# File 'sig/client.rbs', line 425
def delete_browser_settings: (
|
#delete_data_protection_settings(params = {}) ⇒ Struct
Deletes data protection settings.
434 |
# File 'sig/client.rbs', line 434
def delete_data_protection_settings: (
|
#delete_identity_provider(params = {}) ⇒ Struct
Deletes the identity provider.
443 |
# File 'sig/client.rbs', line 443
def delete_identity_provider: (
|
#delete_ip_access_settings(params = {}) ⇒ Struct
Deletes IP access settings.
452 |
# File 'sig/client.rbs', line 452
def delete_ip_access_settings: (
|
#delete_network_settings(params = {}) ⇒ Struct
Deletes network settings.
461 |
# File 'sig/client.rbs', line 461
def delete_network_settings: (
|
#delete_portal(params = {}) ⇒ Struct
Deletes a web portal.
470 |
# File 'sig/client.rbs', line 470
def delete_portal: (
|
#delete_session_logger(params = {}) ⇒ Struct
Deletes a session logger resource.
479 |
# File 'sig/client.rbs', line 479
def delete_session_logger: (
|
#delete_trust_store(params = {}) ⇒ Struct
Deletes the trust store.
488 |
# File 'sig/client.rbs', line 488
def delete_trust_store: (
|
#delete_user_access_logging_settings(params = {}) ⇒ Struct
Deletes user access logging settings.
497 |
# File 'sig/client.rbs', line 497
def delete_user_access_logging_settings: (
|
#delete_user_settings(params = {}) ⇒ Struct
Deletes user settings.
506 |
# File 'sig/client.rbs', line 506
def delete_user_settings: (
|
#disassociate_browser_settings(params = {}) ⇒ Struct
Disassociates browser settings from a web portal.
515 |
# File 'sig/client.rbs', line 515
def disassociate_browser_settings: (
|
#disassociate_data_protection_settings(params = {}) ⇒ Struct
Disassociates data protection settings from a web portal.
524 |
# File 'sig/client.rbs', line 524
def disassociate_data_protection_settings: (
|
#disassociate_ip_access_settings(params = {}) ⇒ Struct
Disassociates IP access settings from a web portal.
533 |
# File 'sig/client.rbs', line 533
def disassociate_ip_access_settings: (
|
#disassociate_network_settings(params = {}) ⇒ Struct
Disassociates network settings from a web portal.
542 |
# File 'sig/client.rbs', line 542
def disassociate_network_settings: (
|
#disassociate_session_logger(params = {}) ⇒ Struct
Disassociates a session logger from a portal.
551 |
# File 'sig/client.rbs', line 551
def disassociate_session_logger: (
|
#disassociate_trust_store(params = {}) ⇒ Struct
Disassociates a trust store from a web portal.
560 |
# File 'sig/client.rbs', line 560
def disassociate_trust_store: (
|
#disassociate_user_access_logging_settings(params = {}) ⇒ Struct
Disassociates user access logging settings from a web portal.
569 |
# File 'sig/client.rbs', line 569
def disassociate_user_access_logging_settings: (
|
#disassociate_user_settings(params = {}) ⇒ Struct
Disassociates user settings from a web portal.
578 |
# File 'sig/client.rbs', line 578
def disassociate_user_settings: (
|
#expire_session(params = {}) ⇒ Struct
Expires an active secure browser session.
587 |
# File 'sig/client.rbs', line 587
def expire_session: (
|
#get_browser_settings(params = {}) ⇒ Types::GetBrowserSettingsResponse
Gets browser settings.
598 |
# File 'sig/client.rbs', line 598
def get_browser_settings: (
|
#get_data_protection_settings(params = {}) ⇒ Types::GetDataProtectionSettingsResponse
Gets the data protection settings.
608 |
# File 'sig/client.rbs', line 608
def get_data_protection_settings: (
|
#get_identity_provider(params = {}) ⇒ Types::GetIdentityProviderResponse
Gets the identity provider.
618 |
# File 'sig/client.rbs', line 618
def get_identity_provider: (
|
#get_ip_access_settings(params = {}) ⇒ Types::GetIpAccessSettingsResponse
Gets the IP access settings.
628 |
# File 'sig/client.rbs', line 628
def get_ip_access_settings: (
|
#get_network_settings(params = {}) ⇒ Types::GetNetworkSettingsResponse
Gets the network settings.
638 |
# File 'sig/client.rbs', line 638
def get_network_settings: (
|
#get_portal(params = {}) ⇒ Types::GetPortalResponse
Gets the web portal.
648 |
# File 'sig/client.rbs', line 648
def get_portal: (
|
#get_portal_service_provider_metadata(params = {}) ⇒ Types::GetPortalServiceProviderMetadataResponse
Gets the service provider metadata.
659 |
# File 'sig/client.rbs', line 659
def get_portal_service_provider_metadata: (
|
#get_session(params = {}) ⇒ Types::GetSessionResponse
Gets information for a secure browser session.
669 |
# File 'sig/client.rbs', line 669
def get_session: (
|
#get_session_logger(params = {}) ⇒ Types::GetSessionLoggerResponse
Gets details about a specific session logger resource.
680 |
# File 'sig/client.rbs', line 680
def get_session_logger: (
|
#get_trust_store(params = {}) ⇒ Types::GetTrustStoreResponse
Gets the trust store.
690 |
# File 'sig/client.rbs', line 690
def get_trust_store: (
|
#get_trust_store_certificate(params = {}) ⇒ Types::GetTrustStoreCertificateResponse
Gets the trust store certificate.
701 |
# File 'sig/client.rbs', line 701
def get_trust_store_certificate: (
|
#get_user_access_logging_settings(params = {}) ⇒ Types::GetUserAccessLoggingSettingsResponse
Gets user access logging settings.
712 |
# File 'sig/client.rbs', line 712
def get_user_access_logging_settings: (
|
#get_user_settings(params = {}) ⇒ Types::GetUserSettingsResponse
Gets user settings.
722 |
# File 'sig/client.rbs', line 722
def get_user_settings: (
|
#list_browser_settings(params = {}) ⇒ Types::ListBrowserSettingsResponse
Retrieves a list of browser settings.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
733 |
# File 'sig/client.rbs', line 733
def list_browser_settings: (
|
#list_data_protection_settings(params = {}) ⇒ Types::ListDataProtectionSettingsResponse
Retrieves a list of data protection settings.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
745 |
# File 'sig/client.rbs', line 745
def list_data_protection_settings: (
|
#list_identity_providers(params = {}) ⇒ Types::ListIdentityProvidersResponse
Retrieves a list of identity providers for a specific web portal.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
757 |
# File 'sig/client.rbs', line 757
def list_identity_providers: (
|
#list_ip_access_settings(params = {}) ⇒ Types::ListIpAccessSettingsResponse
Retrieves a list of IP access settings.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
770 |
# File 'sig/client.rbs', line 770
def list_ip_access_settings: (
|
#list_network_settings(params = {}) ⇒ Types::ListNetworkSettingsResponse
Retrieves a list of network settings.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
782 |
# File 'sig/client.rbs', line 782
def list_network_settings: (
|
#list_portals(params = {}) ⇒ Types::ListPortalsResponse
Retrieves a list or web portals.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
794 |
# File 'sig/client.rbs', line 794
def list_portals: (
|
#list_session_loggers(params = {}) ⇒ Types::ListSessionLoggersResponse
Lists all available session logger resources.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
806 |
# File 'sig/client.rbs', line 806
def list_session_loggers: (
|
#list_sessions(params = {}) ⇒ Types::ListSessionsResponse
Lists information for multiple secure browser sessions from a specific portal.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
818 |
# File 'sig/client.rbs', line 818
def list_sessions: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves a list of tags for a resource.
834 |
# File 'sig/client.rbs', line 834
def list_tags_for_resource: (
|
#list_trust_store_certificates(params = {}) ⇒ Types::ListTrustStoreCertificatesResponse
Retrieves a list of trust store certificates.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
846 |
# File 'sig/client.rbs', line 846
def list_trust_store_certificates: (
|
#list_trust_stores(params = {}) ⇒ Types::ListTrustStoresResponse
Retrieves a list of trust stores.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
859 |
# File 'sig/client.rbs', line 859
def list_trust_stores: (
|
#list_user_access_logging_settings(params = {}) ⇒ Types::ListUserAccessLoggingSettingsResponse
Retrieves a list of user access logging settings.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
871 |
# File 'sig/client.rbs', line 871
def list_user_access_logging_settings: (
|
#list_user_settings(params = {}) ⇒ Types::ListUserSettingsResponse
Retrieves a list of user settings.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
883 |
# File 'sig/client.rbs', line 883
def list_user_settings: (
|
#tag_resource(params = {}) ⇒ Struct
Adds or overwrites one or more tags for the specified resource.
893 |
# File 'sig/client.rbs', line 893
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from the specified resource.
909 |
# File 'sig/client.rbs', line 909
def untag_resource: (
|
#update_browser_settings(params = {}) ⇒ Types::UpdateBrowserSettingsResponse
Updates browser settings.
920 |
# File 'sig/client.rbs', line 920
def update_browser_settings: (
|
#update_data_protection_settings(params = {}) ⇒ Types::UpdateDataProtectionSettingsResponse
Updates data protection settings.
937 |
# File 'sig/client.rbs', line 937
def update_data_protection_settings: (
|
#update_identity_provider(params = {}) ⇒ Types::UpdateIdentityProviderResponse
Updates the identity provider.
951 |
# File 'sig/client.rbs', line 951
def update_identity_provider: (
|
#update_ip_access_settings(params = {}) ⇒ Types::UpdateIpAccessSettingsResponse
Updates IP access settings.
965 |
# File 'sig/client.rbs', line 965
def update_ip_access_settings: (
|
#update_network_settings(params = {}) ⇒ Types::UpdateNetworkSettingsResponse
Updates network settings.
984 |
# File 'sig/client.rbs', line 984
def update_network_settings: (
|
#update_portal(params = {}) ⇒ Types::UpdatePortalResponse
Updates a web portal.
998 |
# File 'sig/client.rbs', line 998
def update_portal: (
|
#update_session_logger(params = {}) ⇒ Types::UpdateSessionLoggerResponse
Updates the details of a session logger.
1013 |
# File 'sig/client.rbs', line 1013
def update_session_logger: (
|
#update_trust_store(params = {}) ⇒ Types::UpdateTrustStoreResponse
Updates the trust store.
1030 |
# File 'sig/client.rbs', line 1030
def update_trust_store: (
|
#update_user_access_logging_settings(params = {}) ⇒ Types::UpdateUserAccessLoggingSettingsResponse
Updates the user access logging settings.
1043 |
# File 'sig/client.rbs', line 1043
def update_user_access_logging_settings: (
|
#update_user_settings(params = {}) ⇒ Types::UpdateUserSettingsResponse
Updates the user settings.
1055 |
# File 'sig/client.rbs', line 1055
def update_user_settings: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4532 4533 4534 |
# File 'lib/aws-sdk-workspacesweb/client.rb', line 4532 def waiter_names [] end |